@@ -7,7 +7,7 @@ from tkinter import scrolledtext
 import os,sys
 # Stupid packaging messes with paths...
 SCRIPT_DIR = os.path.dirname(os.path.abspath(__file__))
-sys.path.append(os.path.dirname(SCRIPT_DIR))
+print("SCRIPT_DIR=",SCRIPT_DIR)
 
 from ScrollText import *
 from TerminalWindow import *
